===========
Change log
===========

v0.1.0
-----------
* First version. Unmodified code from django-ovp-core.

v1.0.0
-----------
* First stable release

v1.0.1
-----------
* Add settings examples to documentation
* Update "Getting Started" and "Documentation" sections on README.rst
* Modify license from AGPL to MIT.
* Remove "Contributing" section from README.rst

v1.0.2
-----------
* Fix documentation badge link

v1.0.3
-----------
Add requirements to MANIFEST.in

v1.0.4[unreleased]
-----------
